# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from basistheory.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from basistheory.model.application import Application
from basistheory.model.application_paginated_list import ApplicationPaginatedList
from basistheory.model.create_application_request import CreateApplicationRequest
from basistheory.model.create_reactor_formula_request import CreateReactorFormulaRequest
from basistheory.model.create_reactor_request import CreateReactorRequest
from basistheory.model.create_token_request import CreateTokenRequest
from basistheory.model.create_token_response import CreateTokenResponse
from basistheory.model.encryption_key import EncryptionKey
from basistheory.model.encryption_metadata import EncryptionMetadata
from basistheory.model.log import Log
from basistheory.model.log_paginated_list import LogPaginatedList
from basistheory.model.pagination import Pagination
from basistheory.model.permission import Permission
from basistheory.model.privacy import Privacy
from basistheory.model.problem_details import ProblemDetails
from basistheory.model.react_request import ReactRequest
from basistheory.model.react_response import ReactResponse
from basistheory.model.reactor import Reactor
from basistheory.model.reactor_formula import ReactorFormula
from basistheory.model.reactor_formula_configuration import ReactorFormulaConfiguration
from basistheory.model.reactor_formula_paginated_list import ReactorFormulaPaginatedList
from basistheory.model.reactor_formula_request_parameter import ReactorFormulaRequestParameter
from basistheory.model.reactor_paginated_list import ReactorPaginatedList
from basistheory.model.search_tokens_request import SearchTokensRequest
from basistheory.model.tenant import Tenant
from basistheory.model.tenant_usage_report import TenantUsageReport
from basistheory.model.token import Token
from basistheory.model.token_metrics import TokenMetrics
from basistheory.model.token_paginated_list import TokenPaginatedList
from basistheory.model.token_report import TokenReport
from basistheory.model.update_application_request import UpdateApplicationRequest
from basistheory.model.update_reactor_formula_request import UpdateReactorFormulaRequest
from basistheory.model.update_reactor_request import UpdateReactorRequest
from basistheory.model.update_tenant_request import UpdateTenantRequest
from basistheory.model.validation_problem_details import ValidationProblemDetails



"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.token_children_api import TokenChildrenApi  # noqa: E501


class TestTokenChildrenApi(unittest.TestCase):
    """TokenChildrenApi unit test stubs"""

    def setUp(self):
        self.api = TokenChildrenApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_association(self):
        """Test case for create_association

        """
        pass

    def test_create_child(self):
        """Test case for create_child

        """
        pass

    def test_delete_association(self):
        """Test case for delete_association

        """
        pass

    def test_get_children(self):
        """Test case for get_children

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "basistheory"
VERSION = "0.7.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

# read contents from README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name=NAME,
    version=VERSION,
    description="BasisTheory Python SDK",
    author="Basis Theory",
    author_email="support@basistheory.com",
    url="https://basistheory.com",
    keywords=["BasisTheory", "Basis Theory", "SDK", "Python"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    project_urls={
      "Documentation": "https://docs.basistheory.com/",
      "Source Code": "https://github.com/Basis-Theory/basistheory-python",
    }
)



# flake8: noqa

"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0-alpha"

# import ApiClient
from basistheory.api_client import ApiClient

# import Configuration
from basistheory.configuration import Configuration
from basistheory.request_options import RequestOptions

# import exceptions
from basistheory.exceptions import OpenApiException
from basistheory.exceptions import ApiAttributeError
from basistheory.exceptions import ApiTypeError
from basistheory.exceptions import ApiValueError
from basistheory.exceptions import ApiKeyError
from basistheory.exceptions import ApiException
